package com.ruoyi.system.service.impl.fgw;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.fgw.FgwJdapDwMapper;
import com.ruoyi.system.domain.fgw.FgwJdapDw;
import com.ruoyi.system.service.fgw.IFgwJdapDwService;

/**
 * 发改委_节点安排_单位Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-04-11
 */
@Service
public class FgwJdapDwServiceImpl implements IFgwJdapDwService 
{
    @Autowired
    private FgwJdapDwMapper fgwJdapDwMapper;

    /**
     * 查询发改委_节点安排_单位
     * 
     * @param id 发改委_节点安排_单位主键
     * @return 发改委_节点安排_单位
     */
    @Override
    public FgwJdapDw selectFgwJdapDwById(Long id)
    {
        return fgwJdapDwMapper.selectFgwJdapDwById(id);
    }

    /**
     * 查询发改委_节点安排_单位列表
     * 
     * @param fgwJdapDw 发改委_节点安排_单位
     * @return 发改委_节点安排_单位
     */
    @Override
    public List<FgwJdapDw> selectFgwJdapDwList(FgwJdapDw fgwJdapDw)
    {
        return fgwJdapDwMapper.selectFgwJdapDwList(fgwJdapDw);
    }

    /**
     * 新增发改委_节点安排_单位
     * 
     * @param fgwJdapDw 发改委_节点安排_单位
     * @return 结果
     */
    @Override
    public int insertFgwJdapDw(FgwJdapDw fgwJdapDw)
    {
        fgwJdapDw.setCreateTime(DateUtils.getNowDate());
        return fgwJdapDwMapper.insertFgwJdapDw(fgwJdapDw);
    }

    /**
     * 修改发改委_节点安排_单位
     * 
     * @param fgwJdapDw 发改委_节点安排_单位
     * @return 结果
     */
    @Override
    public int updateFgwJdapDw(FgwJdapDw fgwJdapDw)
    {
        fgwJdapDw.setUpdateTime(DateUtils.getNowDate());
        return fgwJdapDwMapper.updateFgwJdapDw(fgwJdapDw);
    }

    /**
     * 批量删除发改委_节点安排_单位
     * 
     * @param ids 需要删除的发改委_节点安排_单位主键
     * @return 结果
     */
    @Override
    public int deleteFgwJdapDwByIds(Long[] ids)
    {
        return fgwJdapDwMapper.deleteFgwJdapDwByIds(ids);
    }

    /**
     * 删除发改委_节点安排_单位信息
     * 
     * @param id 发改委_节点安排_单位主键
     * @return 结果
     */
    @Override
    public int deleteFgwJdapDwById(Long id)
    {
        return fgwJdapDwMapper.deleteFgwJdapDwById(id);
    }
}
