package com.ruoyi.web.controller.fgw;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.system.domain.fgw.FgwJdapDw;
import com.ruoyi.system.service.fgw.IFgwJdapDwService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 发改委_节点安排_单位Controller
 * 
 * @author ruoyi
 * @date 2023-04-11
 */
@RestController
@RequestMapping("/fgw/dw")
public class FgwJdapDwController extends BaseController
{
    @Autowired
    private IFgwJdapDwService fgwJdapDwService;

    /**
     * 查询发改委_节点安排_单位列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:dw:list')")
    @GetMapping("/list")
    public TableDataInfo list(FgwJdapDw fgwJdapDw)
    {
        startPage();
        List<FgwJdapDw> list = fgwJdapDwService.selectFgwJdapDwList(fgwJdapDw);
        return getDataTable(list);
    }

    /**
     * 导出发改委_节点安排_单位列表
     */
    @PreAuthorize("@ss.hasPermi('fgw:dw:export')")
    @Log(title = "发改委_节点安排_单位", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, FgwJdapDw fgwJdapDw)
    {
        List<FgwJdapDw> list = fgwJdapDwService.selectFgwJdapDwList(fgwJdapDw);
        ExcelUtil<FgwJdapDw> util = new ExcelUtil<FgwJdapDw>(FgwJdapDw.class);
        util.exportExcel(response, list, "发改委_节点安排_单位数据");
    }

    /**
     * 获取发改委_节点安排_单位详细信息
     */
    @PreAuthorize("@ss.hasPermi('fgw:dw:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(fgwJdapDwService.selectFgwJdapDwById(id));
    }

    /**
     * 新增发改委_节点安排_单位
     */
    @PreAuthorize("@ss.hasPermi('fgw:dw:add')")
    @Log(title = "发改委_节点安排_单位", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody FgwJdapDw fgwJdapDw)
    {
        return toAjax(fgwJdapDwService.insertFgwJdapDw(fgwJdapDw));
    }

    /**
     * 修改发改委_节点安排_单位
     */
    @PreAuthorize("@ss.hasPermi('fgw:dw:edit')")
    @Log(title = "发改委_节点安排_单位", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody FgwJdapDw fgwJdapDw)
    {
        return toAjax(fgwJdapDwService.updateFgwJdapDw(fgwJdapDw));
    }

    /**
     * 删除发改委_节点安排_单位
     */
    @PreAuthorize("@ss.hasPermi('fgw:dw:remove')")
    @Log(title = "发改委_节点安排_单位", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(fgwJdapDwService.deleteFgwJdapDwByIds(ids));
    }
}
